#!/usr/bin/env python3

import pandas as pd

# Read motifs data
motifs_data = pd.read_csv("motifs_in_promoters_with_LT_peak_Category.txt", delimiter="\t")

# Read peak distances data
peak_distances = pd.read_csv("peak_tss_distances.txt", delimiter="\t")

# Merge motifs data with peak distances based on matching PromoterID and Distance to TSS Closest Gene
merged_data = pd.merge(motifs_data, peak_distances, left_on="PromoterID", right_on="Closest Gene (Ensemble ID)", how="left")

# Group the merged data by PromoterID and aggregate the values
aggregated_data = merged_data.groupby("PromoterID").agg(
    {
        "Gene_Symbol": "first",
        "Gene_Type": "first",
        "Gene Strand": lambda x: ", ".join(x.dropna().unique()),
        #"Closest Gene (Ensemble ID)": lambda x: ", ".join(x.dropna().unique()),
        "Peak Name": lambda x: ", ".join(x.dropna()),
        "Distance to TSS": lambda x: ", ".join(x.dropna().astype(str)),
        "Motif_GRGGC_Count": "first",
        "Motif_GRGGC_Center_Positions": "first",
        "Avg_Distance_To_TSS_of_Motif_GRGGC": "first",
        "Class_based_Motif_GRGGC": "first",
        "Motif_GCCYR_Count": "first",
        "Motif_GCCYR_Center_Positions": "first",
        "Avg_Distance_To_TSS_of_Motif_GCCYR": "first",
        "Class_based_Motif_GCCYR": "first",
        "Motifs_GRGGC+GCCYR_Count": "first",
        "Avg_Distance_To_TSS_of_Motifs_GRGGC+GCCYR": "first",
        "Class_based_Motifs_GRGGC+GCCYR": "first",
    }
)

# Rename the columns
#, "Closest Gene (Ensemble ID)": "Peak_Ensemble_ID"
aggregated_data = aggregated_data.rename(columns={"Gene Strand": "Gene_Strand", "Peak Name": "Peak_Name", "Distance to TSS": "Peak_Distance_to_TSS"})

# Save the aggregated data to the new file
aggregated_data.to_csv("_peaks_and_motifs_in_promoters_with_LT_peak.txt", sep="\t")

